-- debuzz
-- replaces station buzz sound with silence

local cp = console_print

local mute_sounds = gkini.ReadInt("sounds", "stationbuzz", 1)

local bstr = function(id, val)
	return val
end

local debuzz = {
	CCD1 = true,
	open = nil,
	config = nil,
	smart_config = {
		title = "Debuzz",
		cb = function(id, val)
			gkini.WriteInt("sounds", "stationbuzz", val == "YES" and 1 or 0)
		end,
		[1] = 'toggle_sound',
		toggle_sound = {
			type = "toggle",
			display = bstr(2, "Mute station signs"),
			[1] = mute_sounds == 1 and "YES" or "NO",
		},
		[2] = "warning",
		warning = {
			type = 'text',
			display = bstr(3, "Game must completely restart to apply"),
			align = "right",
		},
	},
	description = bstr(4, "debuzz mutes the station's neon signs from their ceaseless annoying buzz noise"),
	commands = {},
	manifest = {},
}

local babel, lang_key
local do_babel_support = function()
	babel = lib.get_class("babel", "0")
	lang_key = babel.register("plugins/debuzz/lang/", {'en', 'es', 'fr', 'pt'})
	
	bstr = function(id, val)
		return babel.fetch(lang_key, id, val)
	end
	
	
	
	--redo smart_config for babel support
	debuzz.smart_config = {
		title = "Debuzz",
		cb = function(id, val)
			gkini.WriteInt("sounds", "stationbuzz", val == "YES" and 1 or 0)
		end,
		[1] = 'toggle_sound',
		toggle_sound = {
			type = "toggle",
			display = bstr(2, "Mute station signs"),
			[1] = mute_sounds == 1 and "YES" or "NO",
		},
		[2] = "warning",
		warning = {
			type = 'text',
			display = bstr(3, "Game must completely restart to apply"),
			align = "right",
		},
	}
	debuzz.description = bstr(4, "debuzz mutes the station's neon signs from their ceaseless annoying buzz noise")
	
	lib.set_class("debuzz", "0", debuzz)
end

debuzz.open = function()
	local diag = iup.dialog {
		topmost = "YES",
		fullscreen = "YES",
		bgcolor = "0 0 0 100 *",
		iup.vbox {
			iup.fill { },
			iup.hbox {
				iup.fill { },
				iup.stationbuttonframe {
					iup.vbox {
						iup.hbox {
							iup.label {
								title = "Debuzz " .. bstr(5, "configuration"),
								font = Font.H2,
							},
							iup.fill {
								size = "%20",
							},
							iup.stationbutton {
								title = bstr(1, "Close"),
								action = function(self)
									HideDialog(iup.GetDialog(self))
									iup.Destroy(iup.GetDialog(self))
								end,
							},
						},
						iup.hbox {
							iup.label {
								title = bstr(2, "Mute station signs:"),
							},
							iup.stationtoggle {
								title = "",
								value = mute_sounds > 0 and "ON" or "OFF",
								action = function(self)
									gkini.WriteInt("sounds", "stationbuzz",self.value == "ON" and 1 or 0)
								end,
							},
						},
						iup.fill {
							size = "%4",
						},
						iup.label {
							title = bstr(3, "Restart game to apply!"),
						},
					},
				},
				iup.fill { },
			},
			iup.fill { },
		},
	}
	
	ShowDialog(diag)
end

debuzz.config = debuzz.open

RegisterUserCommand("debuzz", debuzz.open)

local function load_debuzz()
	--[[
		This function actually handles setting the sound
		
		Apparently, GKLoadSound doesn't need to be run even after a reload, as it exists out-of-sandbox (according to the deboop plugin anyways). As such, if a station sign sound is playing when /reload occurs and the sound source switches because of this function, the game might CTD. Need to investigate this...
	]]--
	
	if mute_sounds > 0 then
		cp("Muting billboards!")
		gksound.GKLoadSound {
			soundname = "billboard.buzz",
			filename = "plugins/debuzz/silent.ogg"
		}
		gksound.GKLoadSound {
			soundname = "billboard.buzz.big",
			filename = "plugins/debuzz/silent.ogg"
		}
	else
		cp("Unmuting Billboards!")
		gksound.GKLoadSound {
			soundname = "billboard.buzz",
			filename = "sounds/billboard.waylon.wav",
		}
		gksound.GKLoadSound {
			soundname = "billboard.buzz.big",
			filename = "sounds/billboard.waylon.wav",
		}
	end
	
end

if type(lib) == "table" and lib[0] == "LME" then
	lib.require({{name = "babel", version = "0"}}, do_babel_support)
	cp = lib.log_error
	
	lib.set_class("debuzz", "0", debuzz)
end

load_debuzz()